@@ -144,14 +144,26 @@ def validateSingleURI(service, URI, uriName='', expectedType=None, expectedJson=
             elif payload_resolve != me['payload']:
                 my_logger.error('@odata.id of ReferenceableMember does not point to the correct object: {}'.format(odata_id))
                 counts['badOdataIdResolution'] += 1
+            _, end_fragment = tuple(odata_id.split('#', 1))
+            my_member_id = me['payload'].get('MemberId')
+            if not my_member_id:
+                my_logger.error('ReferenceableMember MemberId does not exist...')
+                counts['badMemberId'] += 1
+            elif my_member_id not in end_fragment.split('/'):
+                my_logger.error('ReferenceableMember MemberId does not match id: {} {}'.format(my_member_id, odata_id))
+                counts['badMemberId'] += 1
         else:
             my_logger.warning('No parent found with which to test @odata.id of ReferenceableMember')
-
+    
     if service.config['uricheck']:
         my_uris = redfish_obj.Type.getUris()
         if odata_id is not None and redfish_obj.Populated and len(my_uris) > 0:
             if redfish_obj.HasValidUri:
                 counts['passRedfishUri'] += 1
+                if not redfish_obj.HasValidUriStrict:
+                    counts['failRedfishUriStrict'] += 1
+                    messages['@odata.id'].result = 'FAIL'
+                    my_logger.error('URI {} does not match object IDs of resource chain'.format(odata_id, redfish_obj.Type))
             else:
                 if '/Oem/' in odata_id:
                     counts['warnRedfishUri'] += 1
@@ -162,6 +174,8 @@ def validateSingleURI(service, URI, uriName='', expectedType=None, expectedJson=
                     messages['@odata.id'].result = 'FAIL'
                     my_logger.error('URI {} does not match the following required URIs in Schema of {}'.format(odata_id, redfish_obj.Type))
 
+
+
     if response and response.getheader('Allow'):
         allowed_responses = [x.strip().upper() for x in response.getheader('Allow').split(',')]
         if not redfish_obj.Type.CanInsert and 'POST' in allowed_responses:
@@ -398,8 +412,7 @@ def validateURITree(service, URI, uriName, expectedType=None, expectedJson=None,
             my_link_type = link.Type.fulltype
             success, my_data, _, _ = service.callResourceURI(link_destination)
             # Using None instead of refparent simply because the parent is not where the link comes from
-            returnVal = validateURITree(service, link_destination, uriName + ' -> ' + link.Name,
-                    my_link_type, my_data, None, allLinks)
+            returnVal = validateURITree(service, link_destination, uriName + ' -> ' + link.Name, my_link_type, my_data, None, allLinks)
             success, linkCounts, linkResults, xlinks, xobj = returnVal
             # refLinks.update(xlinks)
 
